package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0D```````````(``P`!````L)8$"#0```!0Y0```````#0`(``(
M`"@`&@`9``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!4````5````!`````$````!``````````"`!`@`@`0(&-X`
M`!C>```%`````!````$`````X````&`%"`!@!0@4`@``]`8```8`````$```
M`@```!3@```48`4(%&`%"/````#P````!@````0````$````3`$``$R!!`A,
M@00(&````!@````$````!````%#E=&3,W0``S%T%",Q=!0@4````%`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB97AE
M8R]L9"UE;&8N<V\N,0`````(````!`````$```!&<F5E0E-$`,J[#0!A````
M9@`````````<`````````#D`````````+````&,````C``````````````!.
M`````````%0```!,`````````#0````[````80````(````N````5P```!``
M```V````````````````````'@```%`````E````5@`````````K````7P``
M`$T````+````3P```&````!B````*````&4`````````/`````````!3````
M`````%4```!>```````````````&````'0```!(````D````,`````H```!%
M````/@```$(```!<`````````$,````]`````````%(`````````````````
M````````6````"D````7````2@```"T```!``````````````````````P``
M`!L````%````9````%T```!!`````````"`````)````````````````````
M/P````````!9````#P````````!$````1@``````````````````````````
M`````0``````````````````````````````````````````````````````
M````````#0``````````````````````````````````````````````````
M````````````````````````````&@```````````````````!D````(````
M$0```````````````````!0````,````#@`````````5````````````````
M`````````"8````8````````````````````````````````````````````
M```A````$P```````````````````#$````````````````````X````*@``
M```````?````%@```"<```!)`````````#,``````````````$L````B````
M40```"\````````````````````````````````````U````-P````0```!'
M````2````%H``````````````#(````Z````6P````<`````````````````
M````````=@$``````````0``$@```)D#``!@^P0("0```!(`#`"J`P``T)<$
M"$`````2``P`#``````````O````$@````\$````````'0```!(```!G`P``
ML)8$"!D````2``P`%@`````````&!0``$@```&P"`````````````!(````A
M````(&(%"`$````1`!<`30(`````````````$@```#@``````````````"``
M``!A`@``_&$%"`0````1`!8`3`````S_!`@`````$@`-`+<#``!P^P0(]0(`
M`!(`#`#-`P``(.,$"$H````2``P`VP,``+#Z!`BO````$@`,`%(`````````
MWP,``!(```!;````*&(%"`$````1`!<`9@````````!C`P``$@```'0`````
M````1@```!(```#Q`P``@.H$"/4````2``P`_0,``&#J!`@?````$@`,`(0`
M``!`8@4(`0```!$`%P"2`````````$0!```2````HP(````````K````$@``
M`.0"````````-````!(````8!```@.L$"&0````2``P`+0(``$AB!0@$````
M$0`7`%0#````````-@```!(````*`P`````````````2````10,```````!T
M````$@```*````!08@4(!````!$`%P`R`P`````````````2````J@``````
M```^````$@```!@#````````!0```!(```"U`````````%8#```2````30,`
M``````!:````$@```#$$``#@`04(ZEL``!$`#@##````5&(%"`0````1`!<`
M*0,````````T````$@```/0"`````````````!(```#)`````````"D````2
M````F`(```````!W````$@```-<```!@8@4(!````!$`%P")`@```````(L`
M```2````Y````)"4!`AI!```$@```)X"`````````````!(```#T````9&(%
M"`$````1`!<`_P`````````Z`0``$@```!`!````````0@<``!(````Q`P``
M```````````2````'P$``&AB!0@$````$0`7`"(#`````````````!(```![
M`@`````````````2````=0(`````````````$@```"0$``!P_@0()````!(`
M#`"!`@```````)@````2````+P$```````"$`@``$@```#T!````````XAH`
M`!(```"J`@`````````````2````^@(```````!-````$@```-,"````````
M&@```!(```!B`P``%&(%"``````0`/'_2P$``/!F!0@$````$0`7`%,!````
M````N@```!(```!9`@```````&X%```2`````@,````````6````$@```)`"
M````````*P```!(````L!```#&(%"`0````1`!8`4@(```````!)````$@``
M`%\!``!L8@4(!````!$`%P!`!```<.,$""@````2``P`.P(``(!B!0@@````
M$0`7`#<#````````@P```!(```!N`P``]&8%"``````0`/'_L0(`````````
M````$@```!$#````````0````!(```!J`0```````$$````2````7`0``!!B
M!0@$````$0`6`,`"``"@8@4(!````!$`%P!]`0```````(T````2````B@$`
M`*1B!0@!````$0`7`)<!``"E8@4($P```!$`%P"E`@```````$,````2````
M<`0``*#O!`@'"P``$@`,`*8!````````*@```!(```!;`P``%&(%"``````0
M`/'_$0`````````9`0``$@```+$!````````S0(``!(```!]!```H.<$"!$!
M```2``P`CP0``,#M!`C<`0``$@`,`+P!````````2````!(```"X`@``````
M`$D````2````ZP(```````"C````$@```#X#````````<P```!(```"<!```
MP.@$")(!```2``P`J00``/#K!`C0`0``$@`,`"8$``#<D@0(`````!(`"@#+
M`0``N&(%"`0````1`!<`U0$```````!]````$@```.P!````````=0D``!(`
M````;&EB<&5R;"YS;P!P97)L7V9R964`<&5R;%]P87)S90!03%]P97)L7V1E
M<W1R=6-T7VQE=F5L`%]*=E]296=I<W1E<D-L87-S97,`7V9I;FD`<&5R;%]R
M=6X`4$Q?:6Y?979A;`!097)L7V%V7W-H:69T`%!E<FQ?9W9?9F5T8VAP=@!0
M3%]E>&ET7V9L86=S`%!E<FQ?<W9?<V5T<'8`4$Q?8V]M<&-V`'!E<FQ?86QL
M;V,`4&5R;%]D;W5N=VEN9`!03%]O<`!097)L7W-Y<U]T97)M`%!,7V5V86Q?
M<F]O=`!B;V]T7T1Y;F%,;V%D97(`4$Q?=&%I;G1E9`!097)L7VYE=UA37V9L
M86=S`'!E<FQ?8V]N<W1R=6-T`%!,7V-U<G-T86-K:6YF;P!097)L7V%V7V9E
M=&-H`'!E<FQ?9&5S=')U8W0`96YV:7)O;@!097)L7VUG7W-E=`!03%]T;W!?
M96YV`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7VYE=U-6<'8`4$Q?9&]?=6YD
M=6UP`%!,7VUE;6]R>5]W<F%P`%!E<FQ?8W)O86L`4&5R;%]N97=84P!097)L
M7W-Y<U]I;FET,P!03%]P87)S97(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!0
M97)L7W-V7S)P=E]F;&%G<P!L:6)M+G-O+C4`;&EB8W)Y<'0N<V\N-0!L:6)U
M=&EL+G-O+CD`;&EB8RYS;RXW`%]?;6)?<V)?;&EM:70`7U]S=&%C:U]C:&M?
M9W5A<F0`;W!E;@!M96UC<'D`<F5A;&QO8P!?7W!R;V=N86UE`')E861L:6YK
M`')M9&ER`&UK9&ER`'-T<FYC;7``<W1R;&5N`&]P96YD:7(`;'-E96L`<F5A
M9`!A=&5X:70`86-C97-S`&=E='!I9`!M96UM;W9E`%]#=7)R96YT4G5N94QO
M8V%L90!?7W-T86-K7V-H:U]F86EL`'-T<G1O:P!C;&]S961I<@!C;&]S90!S
M=')N8W!Y`%]?97)R;W(`=6YL:6YK`&UE;7-E=`!?:6YI=%]T;',`9V5T=6ED
M`'-P<FEN=&8`;'-T870`<W1R<W1R`'-T<F-M<`!R96%D9&ER`'-T<F1U<`!E
M>&5C=G``7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O
M<&5R;#4O-2XQ,BXT+VUA8V@O0T]210!P87)?8W5R<F5N=%]E>&5C`'!A<E]B
M87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``>'-?:6YI=`!N86UE7VQO861?
M;7E?<&%R7W!L`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!S:7IE7VQO
M861?;7E?<&%R7W!L`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C```````@`!
M``$````"``$````"`````@````$``0`!``$``0````````````$``0``````
M`@`"``$``@`"``(``@````(````"`````@`!`````@`"`````@````(````"
M``````````(````"``(``@`!``(```````(``@`"``$``0````(``@`"``$`
M`@````$``@`"``$``@`"`````0`"``````````(``0````$``@````$``0``
M``(``@`"``$``0`!``````````$``0`C`@``$`````````"P*'H'```"`*X$
M````````(&(%"`4)```H8@4(!1(``$!B!0@%%P``2&(%"`4<``!08@4(!2``
M`%1B!0@%)P``8&(%"`4L``!D8@4(!3```&AB!0@%-```;&(%"`5'``"`8@4(
M!4D``*!B!0@%4```I&(%"`52``"E8@4(!5,``+AB!0@%8P``$&$%"`<!```4
M804(!P0``!AA!0@'!0``'&$%"`<'```@804(!P@``"1A!0@'"@``*&$%"`<1
M```L804(!Q,``#!A!0@'%```-&$%"`<8```X804(!QD``#QA!0@'&@``0&$%
M"`<=``!$804(!QX``$AA!0@''P``3&$%"`<A``!0804(!R(``%1A!0@'(P``
M6&$%"`<D``!<804(!R4``&!A!0@'*```9&$%"`<I``!H804(!RH``&QA!0@'
M*P``<&$%"`<M``!T804(!RX``'AA!0@'+P``?&$%"`<Q``"`804(!S(``(1A
M!0@',P``B&$%"`<U``",804(!S8``)!A!0@'-P``E&$%"`<Y``"8804(!SH`
M`)QA!0@'.P``H&$%"`<\``"D804(!ST``*AA!0@'/@``K&$%"`=!``"P804(
M!T(``+1A!0@'0P``N&$%"`=$``"\804(!T8``,!A!0@'2@``Q&$%"`=,``#(
M804(!TT``,QA!0@'3@``T&$%"`=1``#4804(!U0``-AA!0@'5@``W&$%"`=8
M``#@804(!UD``.1A!0@'7```Z&$%"`==``#L804(!UX``/!A!0@'7P``]&$%
M"`=D``#X804(!V4``(/L#.B\!```Z/=K``"#Q`S#````_S4(804(_R4,804(
M`````/\E$&$%"&@`````Z>#_____)11A!0AH"````.G0_____R48804(:!``
M``#IP/____\E'&$%"&@8````Z;#_____)2!A!0AH(````.F@_____R4D804(
M:"@```#ID/____\E*&$%"&@P````Z8#_____)2QA!0AH.````.EP_____R4P
M804(:$````#I8/____\E-&$%"&A(````Z5#_____)3AA!0AH4````.E`____
M_R4\804(:%@```#I,/____\E0&$%"&A@````Z2#_____)41A!0AH:````.D0
M_____R5(804(:'````#I`/____\E3&$%"&AX````Z?#^____)5!A!0AH@```
M`.G@_O___R54804(:(@```#IT/[___\E6&$%"&B0````Z<#^____)5QA!0AH
MF````.FP_O___R5@804(:*````#IH/[___\E9&$%"&BH````Z9#^____)6AA
M!0AHL````.F`_O___R5L804(:+@```#I</[___\E<&$%"&C`````Z6#^____
M)71A!0AHR````.E0_O___R5X804(:-````#I0/[___\E?&$%"&C8````Z3#^
M____)8!A!0AHX````.D@_O___R6$804(:.@```#I$/[___\EB&$%"&CP````
MZ0#^____)8QA!0AH^````.GP_?___R60804(:``!``#IX/W___\EE&$%"&@(
M`0``Z=#]____)9AA!0AH$`$``.G`_?___R6<804(:!@!``#IL/W___\EH&$%
M"&@@`0``Z:#]____):1A!0AH*`$``.F0_?___R6H804(:#`!``#I@/W___\E
MK&$%"&@X`0``Z7#]____);!A!0AH0`$``.E@_?___R6T804(:$@!``#I4/W_
M__\EN&$%"&A0`0``Z4#]____);QA!0AH6`$``.DP_?___R7`804(:&`!``#I
M(/W___\EQ&$%"&AH`0``Z1#]____)<AA!0AH<`$``.D`_?___R7,804(:'@!
M``#I\/S___\ET&$%"&B``0``Z>#\____)=1A!0AHB`$``.G0_/___R78804(
M:)`!``#IP/S___\EW&$%"&B8`0``Z;#\____)>!A!0AHH`$``.F@_/___R7D
M804(:*@!``#ID/S___\EZ&$%"&BP`0``Z8#\____)>QA!0AHN`$``.EP_/__
M_R7P804(:,`!``#I8/S___\E]&$%"&C(`0``Z5#\____)?AA!0AHT`$``.E`
M_/__,>U5B>6#Y/"-10B#[`10_W4$4N@(````S)"0D)"0D)!5B>575E.#[`R+
M=0R+71"%]HU\LP2)/?!F!0A^-8L#A<!T+Z/\804(#[80A-)T(X/``>L*#[80
M@\`!A-)T%(#Z+W7QH_QA!0@/MA"#P`&$TG7LN!1@!0B%P'0TBT4(B00DZ&K\
M___'!"0,_P0(Z%[\___HE?O__XE\)`B)7"0$B30DZ)E4``")!"3HL?[__^BL
M_/__Z]"0D)"0D)"0D)"058GE@^P(@#V\8@4(`'0,ZQR#P`2C!&(%"/_2H01B
M!0B+$(72=>O&!;QB!0@!R<.058GE@^P(H1!@!0B%P'02N`````"%P'0)QP0D
M$&`%"/_0R<.0D)"0D)"0D)"0D)"058GE5HMU"%,/M@Z)\X3)="FA*`$%"(U6
M`0^V`.L,9I`/M@J#P@&$R700.,%U\@^V"HG3@\(!A,EU\(G86UY=PU6)Y5=6
M4X'LO`L``(F%E/G__X/`.(F%G/G__\>%F/G__P````"+E9SY__^+`HM2!(.%
MG/G__PB)A:#Y__^+M:#Y__^)P8F5I/G__XN]I/G__XG3#Z3+"#';#Z3"&#'2
MP>$("=/!X!B!X0``_P`/K/X()0```/^)M:#Y__\)P8N%H/G__\'O"`G3#ZS^
M$(FUH/G__\'O$"4`_P``"<$/MH6@^?__B;VD^?__B[V8^?__B<X)QHG8"=")
MA/UT_?__B;3]</W__XN]I/G__XNUH/G__P^L_@C![PB)\8GPB?N)^@^DRP@Q
MVP^DPA@QTL'A"`G3P>`8@>$``/\`)0```/\)P0^L_@@)T\'O"(GP)0#_```/
MK/X0"<'![Q")\(N]F/G__R7_````B<X)QHG8"=")M/UX_?__B83]?/W__X/'
M`H/_$(F]F/G__P^%U?[__XVUV/W__XU]V(VT)@````"+#HM>!(M&V(M6W,=&
M'``````QR#':,T:H,U:L,T:8,U:<B<&)TP^LV1\/I,(!`<`)P8E.&(/&",'K
M'SG^=<&+E93Y__^+O93Y__^+`HM2!(F%(/7__XN-(/7__XF5)/7__XN5E/G_
M_XMW"(M_#(N=)/7__XFU*/7__XF]+/7__XN]E/G__XM"$(M2%(F%J/G__XN%
ME/G__XF5K/G__XMW&(M_'(N5)/7__XFUL/G__XNU</W__XF]M/G__P-P((N%
M(/7__X'&F7F"6@^DRP4/K-`;P>$%"<B+C:CY___!ZAL!QHN%*/7__R.-*/7_
M__?0(X6P^?__"<@!QHFUJ/O__\>%K/O__P````"+O2SU__^+A2CU__^+M2CU
M__^+E2SU__^+C2#U__^+G23U__\/K/X"#Z3"'HN5?/W__\'@'@G&BX5X_?__
MP>\",?\!A;#Y__\1E;3Y__^+A2#U__^+E23U__^!A;#Y__^9>8):@Y6T^?__
M`"'Q]]`A^R.%J/G___?2(Y6L^?__"<&+A:C[__\)TXN5K/O__P&-L/G__Q&=
MM/G__XN-J/O__XN=K/O__P^LT!O!ZALQT@^DRP7!X04)R`&%L/G__Q&5M/G_
M_XN5L/G__XN%(/7__\>%;/K__P````#'A;SY__\`````B95H^O__BY4D]?__
M#ZS0`L'J`HF%B/G__XN%(/7__XF5C/G__XN5)/7__XN-B/G__P^DPAZ+E83]
M___!X!X)P8N%@/W__P&%J/G__XN%J/O__Q&5K/G__X&%J/G__YEY@EJ#E:SY
M__\`,=(QV_?0B8VX^?__BXVH^___]](CC;CY__\A\"'Z(=L)VHN=;/K__PG(
MBXUH^O__`86H^?__$96L^?__BX5H^O__BY5L^O__#Z3+!<'A!0^LT!L)R,'J
M&S'2`86H^?__$96L^?__BY6H^?__BX6H^___QX6\_/__`````,>%M/O__P``
M``")E;C\__^+E:S[__\/K-`"P>H"B86`^?__BX6H^___B96$^?__BY6L^___
MBXV`^?__#Z3"'HN5C/W__\'@'@G!BX6(_?__B8VP^___BXUH^O__!9EY@EJ)
MA7CY__^+A6CZ__^#T@`!M7CY__^)E7SY___WT!&]?/G__S'2(XVP^___,=LC
MA;CY___WTB'Z(=L)VHN=O/S__PG(BXVX_/__`85X^?__$95\^?__BX6X_/__
MBY6\_/__#Z3+!<'A!0^LT!L)R,'J&S'2`85X^?__$95\^?__BY5X^?__B[UL
M^O__BX5H^O__B[5H^O__B94P_/__BY5L^O__BXVX_/__QX4T_/__``````^L
M_@(/I,(>BY64_?__P>`>"<:+A9#]___![P(Q_P69>8):B85P^?__BX6X^?__
M@](``85P^?__BX6X_/__B95T^?__BY6\^?__$95T^?__,=(QV_?2]]`A\2.%
ML/O__R'[(?H)VHN=-/S__PG(BXTP_/__`85P^?__$95T^?__BX4P_/__BY4T
M_/__#Z3+!<'A!0^LT!L)R,'J&S'2`85P^?__$95T^?__BY5P^?__BX6X_/__
MQX4,^___`````,>%Q/S__P````")E0C[__^+E;S\__\/K-`"P>H"B85H^?__
MBX6X_/__B95L^?__BY6\_/__BXUH^?__#Z3"'HN5G/W__\'@'@G!BX68_?__
MB8W`_/__BXTP_/__!9EY@EJ)A6#Y__^+A;#[__^#T@`!A6#Y__^+A3#\__^)
ME63Y__^+E;3[__\1E63Y__\QTB.-P/S__S';]]#WTB'P(?HAVPG("=H!A6#Y
M__\1E63Y__^+E0S[__^+C0C[__^+A0C[__^+G0S[___'A<3Y__\`````QX4\
M_/__``````^LT!L/I,L%P>$%"<C!ZALQT@&%8/G__Q&59/G__XN58/G__XN%
M,/S__XF5P/G__XN5-/S__P^LT`+!Z@*)A5CY__^+A3#\__^)E5SY__^+E33\
M__^+C5CY__\/I,(>BY6D_?__P>`>"<&+A:#]__^)C3C\__^+C0C[__\%F7F"
M6HF%4/G__XN%"/O__X/2``&U4/G__XF55/G___?0$;U4^?__,=(CC3C\__\Q
MVR.%P/S___?2(?HAVPG:"<@!A5#Y__\1E53Y__^+C<#Y__^+E<3Y__^+A<#Y
M__^+G<3Y__^+O0S[__^+M0C[__\/K-`;#Z3+!<'A!0G(BXW`^?__P>H;,=(!
MA5#Y__\1E53Y__^+E5#Y__\/K/X"BX4(^___P>\",?_'A;S[__\`````B96X
M^___BY4,^___#Z3"'HN5K/W__\'@'@G&BX6H_?__!9EY@EJ)A4CY__^+A<#\
M__^#T@`!A4CY__^+A<#Y__^)E4SY__^+E<3\__\1E4SY__\QTC';]]+WT"'Q
M(X4X_/__(?LA^@G:"<@!A4CY__\1E4SY__^+C;C[__^+E;S[__^+A;C[__^+
MG;S[___'A73Z__\`````QX7,^?__``````^LT!L/I,L%P>$%"<C!ZALQT@&%
M2/G__Q&53/G__XN52/G__XN%P/G__XF5</K__XN5Q/G__P^LT`+!Z@*)A4#Y
M__^+A<#Y__^)E43Y__^+E<3Y__^+C4#Y__\/I,(>BY6T_?__P>`>"<&+A;#]
M__^)C<CY__\%F7F"6HF%./G__X/2`(N%./S__P&%./G__XF5//G__XN5//S_
M_Q&5//G__S'2BX6X^___,=OWTHN-N/O__R'Z(=LCC<CY__\)VHN==/K___?0
M(?`)R(N-</K__P&%./G__Q&5//G__XN%</K__XN5=/K__P^DRP7!X07'A<S\
M__\`````QX7$^___``````^LT!L)R,'J&S'2`84X^?__$94\^?__BY4X^?__
MBX6X^___B97(_/__BY6\^___#ZS0`L'J`HF%,/G__XN%N/O__XF5-/G__XN5
MO/O__XN-,/G__P^DPAZ+E;S]___!X!X)P8N%N/W__XF-P/O__P69>8):@](`
MB84H^?__B94L^?__BX5P^O__`;4H^?__BXUP^O__$;TL^?__,=(CC<#[___W
MT".%R/G__S';]](AVXNU</K__R'ZB[UT^O__"=H)R(N=S/S__P&%*/G__Q&5
M+/G__XN-R/S__XN5S/S__XN%R/S__\>%1/S__P`````/I,L%P>$%#ZS0&PG(
MP>H;,=(!A2CY__\1E2SY__^+E2CY__\/K/X"BX5P^O__P>\",?^)E4#\__^+
ME73Z__\/I,(>BY7$_?__P>`>"<:+A<#]__\%F7F"6H/2`(F%(/G__XF5)/G_
M_XN%R/G__P&%(/G__XN%R/S__XN-R/S__XN5S/G__Q&5)/G__S'2]]`QVR.%
MP/O___?2(?$A^R'Z"=H)R(N=1/S__P&%(/G__Q&5)/G__XN-0/S__XN51/S_
M_XN%0/S__\>%%/O__P`````/I,L%P>$%#ZS0&PG(P>H;,=(!A2#Y__\1E23Y
M__^+E2#Y__^+A<C\__^)E1#[__^+E<S\__\/K-`"P>H"B848^?__BX7(_/__
MB94<^?__BY7,_/__BXT8^?__#Z3"'L'@'@G!B8W0_/__BX7(_?__BY7,_?__
MBXU`_/__QX74_/__``````69>8):B840^?__BX7`^___@](``840^?__BX5`
M_/__B944^?__BY7$^___$944^?__,=(CC=#\__\QV_?0]](A\"'Z(=L)R(N-
M$/O__PG:BYT4^___`840^?__$944^?__BX40^___BY44^___#Z3+!<'A!<>%
MU/G__P`````/K-`;"<C!ZALQT@&%$/G__Q&5%/G__XN5$/G__XN%0/S__XF5
MT/G__XN51/S__P^LT`+!Z@*)A0CY__^+A4#\__^)E0SY__^+E43\__^+C0CY
M___'A4S\__\`````#Z3"'HN5U/W__\'@'@G!BX70_?__B8U(_/__BXT0^___
M!9EY@EJ)A0#Y__^+A1#[__^#T@`!M0#Y__^)E03Y___WT!&]!/G__S'2(XU(
M_/__,=LCA=#\___WTB'Z(=L)VHN=U/G__PG(BXW0^?__`84`^?__$94$^?__
MBX70^?__BY74^?__#Z3+!<'A!0^LT!L)R,'J&S'2`84`^?__$94$^?__BY4`
M^?__B97(^___B[T4^___BX40^___B[40^___BY44^___BXW0^?__QX7,^___
M``````^L_@(/I,(>BY7<_?__P>`>"<:+A=C]___![P(Q_P69>8):B87X^/__
MBX70_/__@](``87X^/__BX70^?__B97\^/__BY74_/__$97\^/__,=(QV_?2
M]]`A\2.%2/S__R'[(?H)VHN=S/O__PG(BXW(^___`87X^/__$97\^/__BX7(
M^___BY7,^___#Z3+!<'A!0^LT!L)R,'J&S'2`87X^/__$97\^/__BY7X^/__
MB95X^O__BY74^?__BX70^?__QX5\^O__`````,>%W/G__P`````/K-`"P>H"
MB87P^/__BX70^?__B97T^/__BY74^?__BXWP^/__#Z3"'HN5Y/W__\'@'@G!
MBX7@_?__B8W8^?__BXW(^___!9EY@EJ)A>CX__^+A4C\__^#T@`!A>CX__^+
MA<C[__^)E>SX__^+E4S\__\1E>SX__\QTB.-V/G__S';]]#WTB'P(?HAVPG(
MBXUX^O__"=J+G7SZ__\!A>CX__\1E>SX__^+A7CZ__^+E7SZ__\/I,L%P>$%
M#ZS0&PG(P>H;,=(!A>CX__\1E>SX__^+E>CX__^+A<C[___'A=S\__\`````
MQX74^___`````(F5V/S__XN5S/O__P^LT`+!Z@*)A>#X__^+A<C[__^)E>3X
M__^+E<S[__^+C>#X__\/I,(>BY7L_?__P>`>"<&+A>C]__^)C=#[__^+C7CZ
M__\%F7F"6HF%V/C__XN%>/K__X/2``&UV/C__XF5W/C___?0$;W<^/__,=(C
MC=#[__\QVR.%V/G___?2(?HAVPG:BYW<_/__"<B+C=C\__\!A=CX__\1E=SX
M__^+A=C\__^+E=S\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A=CX__\1E=SX__^+
ME=CX__^+O7SZ__^+A7CZ__^+M7CZ__^)E5#\__^+E7SZ__^+C=C\___'A53\
M__\`````#ZS^`@^DPAZ+E?3]___!X!X)QHN%\/W__\'O`C'_!9EY@EJ)A=#X
M__^+A=CY__^#T@`!A=#X__^+A=C\__^)E=3X__^+E=SY__\1E=3X__\QTC';
M]]+WT"'Q(X70^___(?LA^@G:BYU4_/__"<B+C5#\__\!A=#X__\1E=3X__^+
MA5#\__^+E53\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A=#X__\1E=3X__^+E=#X
M__^+A=C\___'A1S[__\`````QX7D_/__`````(F5&/O__XN5W/S__P^LT`+!
MZ@*)A<CX__^+A=C\__^)E<SX__^+E=S\__^+C<CX__\/I,(>BY7\_?__P>`>
M"<&+A?C]__^)C>#\__^+C5#\__\%F7F"6HF%P/C__XN%T/O__X/2``&%P/C_
M_XN%4/S__XF5Q/C__XN5U/O__Q&5Q/C__S'2(XW@_/__,=OWT/?2(?`A^B';
M"<@)V@&%P/C__Q&5Q/C__XN5'/O__XN-&/O__XN%&/O__XN='/O__\>%Y/G_
M_P````#'A5S\__\`````#ZS0&P^DRP7!X04)R,'J&S'2`87`^/__$97$^/__
MBY7`^/__BX50_/__B97@^?__BY54_/__#ZS0`L'J`HF%N/C__XN%4/S__XF5
MO/C__XN55/S__XN-N/C__P^DPAZ+E03^___!X!X)P8N%`/[__XF-6/S__XN-
M&/O__P69>8):B86P^/__BX48^___@](``;6P^/__B96T^/__]]`1O;3X__\Q
MTB.-6/S__S';(X7@_/__]](A^B';"=H)R`&%L/C__Q&5M/C__XN-X/G__XN5
MY/G__XN%X/G__XN=Y/G__\>%W/O__P````#'A23[__\`````#ZS0&P^DRP6+
MG1S[___!X04)R(N-&/O__\'J&S'2`86P^/__$96T^/__BY6P^/__#ZS9`HN%
M&/O__XG.BXW@^?__P>L"BYW<^___B978^___BY4<^___#Z3"'HN5W/O__\'@
M'@G&BX7@^?__B;4@^___B[4(_O__]]"!QIEY@EH#M>#\__\CC2#[__\CA5C\
M__\)R(N-V/O__P'&BX78^___#Z3+!0^LT!O!X04)R,'J&P'&B;6`^O__BYWD
M^?__BX7@^?__BXW@^?__BY7D^?__B[40_O__QX6$^O__`````(N]W/O__P^L
MV0(/I,(>BY6$^O__P>`>"<&+A2#[___!ZP(QVX'&H>O9;@.U6/S__S'(,X78
M^___QX7L_/__``````'&BX6`^O__#ZS0&\'J&XF%&/7__XN%@/K__XF5'/7_
M_XN5A/K__P^DP@7!X`6)A:CX__^+A1CU__\+A:CX__^)E:SX__^+E=S[__\!
MQHN%V/O__XFUZ/S__XNUV/O__P^DPAZ+E1S^__\/K/X"P>`>"<:+A1C^___!
M[P(Q_P6AZ]ENB86@^/__@](`BX4@^___`86@^/__B?")E:3X__^+E23[__\1
ME:3X__^)^C':,<@QVC.%@/K__P&%H/C__Q&5I/C__XN%Z/S__XN5[/S__\>%
M9/S__P`````/K-`;P>H;B840]?__BX7H_/__B944]?__BY7L_/__#Z3"!<'@
M!8F%F/C__XN%$/7__PN%F/C__XF5G/C__S'2`86@^/__$96D^/__BY6@^/__
MBX6`^O__B95@_/__BY6$^O__#ZS0`L'J`HF%D/C__XN%@/K__XF5E/C__XN5
MA/K__P^DPAZ)E0SU__^+E9#X___!X!Z)A0CU__\)PHF5B/C__XN%E/C__PN%
M#/7__XF5B/K__XN5)/[__\>%C/K__P````")A8SX__^+A2#^___'A2S[__\`
M````!:'KV6Z)A8#X__^+A8CZ__^#T@`!C8#X__^+C6#\__^)E83X__\1G83X
M__\QTC'Z,?`QVHN=9/S__S.%Z/S__P&%@/C__Q&5A/C__XN%8/S__P^DRP6+
ME63\___!X06+G>S\__\/K-`;"<B+C>C\___!ZALQT@&%@/C__Q&5A/C__XN5
M@/C__P^LV0*+A>C\___!ZP(QVXF5*/O__XN5[/S__P^DPAZ+E2S^___!X!X)
MP8N%*/[__P6AZ]ENB85X^/__BX6(^O__@](``;5X^/__B[4H^___B95\^/__
M$;U\^/__,=(QVC'(B[TL^___,X5@_/__,=H!A7CX__\1E7SX__^+A2C[__\/
MI/<%BY4L^___P>8%B[UD_/__QX7L^?__``````^LT!L)\(NU8/S__\'J&S'2
M`85X^/__$95\^/__BY5X^/__#ZS^`HN%8/S__\'O`C'_B97H^?__BY5D_/__
M#Z3"'HN5-/[__\'@'@G&BX4P_O__!:'KV6Z#T@")A7#X__^+A8CZ__^)E73X
M__^+E8SZ__\!A7#X__^)\!&5=/C__XGZ,=HQR#':,X4H^___`85P^/__$95T
M^/__BX7H^?__BY7L^?__QX7D^___``````^LT!O!ZAN)A0#U__^+A>CY__^)
ME03U__^+E>SY__\/I,(%P>`%B85H^/__BX4`]?__"X5H^/__B95L^/__,=(!
MA7#X__\1E73X__^+E7#X__^+A2C[__^)E>#[__^+E2S[__\/K-`"P>H"B85@
M^/__BX4H^___B95D^/__BY4L^___#Z3"'L'@'HF%^/3__XF5_/3__XN58/C_
M_\>%-/O__P`````)PHN%9/C__PN%_/3__XF5,/O__XF56/C__XN5//[__XF%
M7/C__XN%./[__P6AZ]ENB850^/__BX4P^___@](``8U0^/__BXW@^___B954
M^/__$9U4^/__,=(Q^C'P,=J+G>3[__\SA>CY__\!A5#X__\1E53X__^+A>#[
M__\/I,L%BY7D^___P>$%#ZS0&PG(P>H;,=(!A5#X__\1E53X__^+E5#X__^)
ME9#Z__^+G>SY__^+A>CY__^+C>CY__^+E>SY___'A93Z__\`````QX7T_/__
M``````^LV0(/I,(>BY5$_O__P>`>"<&+A4#^___!ZP(QVP6AZ]ENB85(^/__
MBX4P^___@](``;5(^/__B[60^O__B95,^/__$;U,^/__,=(QVC'(B[V4^O__
M,X7@^___,=H!A4CX__\1E4SX__^+A9#Z__\/I/<%BY64^O__P>8%B[WD^___
M#ZS0&PGPB[7@^___P>H;,=(!A4CX__\1E4SX__^+E4CX__\/K/X"BX7@^___
MP>\",?^)E?#\__^+E>3[__\/I,(>BY5,_O__P>`>"<:+A4C^__\%H>O9;HF%
M0/C__X/2`(N%,/O__P&%0/C__XGPB95$^/__BY4T^___$95$^/__B?HQVC'(
M,=HSA9#Z__\!A4#X__\1E43X__^+A?#\__^+E?3\___'A6S\__\`````#ZS0
M&\'J&XF%\/3__XN%\/S__XF5]/3__XN5]/S__P^DP@7!X`6)A3CX__^+A?#T
M__\+A3CX__^)E3SX__\QT@&%0/C__Q&51/C__XN50/C__XN%D/K__XF5:/S_
M_XN5E/K__P^LT`+!Z@*)A3#X__^+A9#Z__^)E33X__^+E93Z___'A9SZ__\`
M````#Z3"'HF5[/3__XN5,/C__\'@'HF%Z/3__PG"BX4T^/__"X7L]/__B968
M^O__B94H^/__BY54_O__B84L^/__BX50_O__!:'KV6Z)A2#X__^+A9CZ__^#
MT@`!C2#X__^+C6C\__^)E23X__\1G23X__\QTC'Z,?`QVHN=;/S__S.%\/S_
M_P&%(/C__Q&5)/C__XN%:/S__P^DRP6+E6S\___!X04/K-`;"<C!ZALQT@&%
M(/C__Q&5)/C__XN5(/C__XN=]/S__XN%\/S__XN-\/S__XF5./O__XN5]/S_
M_\>%//O__P`````/K-D"#Z3"'HN57/[__\'@'@G!BX58_O__P>L",=L%H>O9
M;HF%&/C__XN%F/K__X/2``&U&/C__XNU./O__XF5'/C__Q&]'/C__S'2,=HQ
MR(N]//O__S.%:/S__S':`848^/__$94<^/__BX4X^___#Z3W!8N5//O__\'F
M!0^LT!L)\,'J&S'2`848^/__$94<^/__BY48^/__B97P^?__B[UL_/__BX5H
M_/__B[5H_/__BY5L_/__QX7T^?__``````^L_@(/I,(>BY5D_O__P>`>"<:+
MA6#^___![P(Q_P6AZ]ENB840^/__@](`BX68^O__`840^/__B?")E13X__^+
ME9SZ__\1E13X__^)^C':,<@QVC.%./O__P&%$/C__Q&5%/C__XN%\/G__XN5
M]/G__P^LT!O!ZAN)A>#T__^+A?#Y__^)E>3T__^+E?3Y__\/I,(%P>`%B84(
M^/__BX7@]/__"X4(^/__B94,^/__,=(!A1#X__\1E13X__^+E1#X__^+A3C[
M___'A>S[__\`````QX5$^___`````(F5Z/O__XN5//O__P^LT`+!Z@*)A0#X
M__^+A3C[__^)E03X__^+E3S[__\/I,(>B97<]/__BY4`^/__P>`>B878]/__
M"<*+A03X__\+A=ST__^)E4#[__^)E?CW__^+E6S^__^)A?SW__^+A6C^__\%
MH>O9;HF%\/?__XN%0/O__X/2``&-\/?__XF5]/?__Q&=]/?__S'2,?HQ\#':
M,X7P^?__`87P]___$97T]___BY7L^___BXWH^___BX7H^___BYWL^___QX6D
M^O__``````^LT!L/I,L%BYWT^?__P>$%"<B+C?#Y___!ZALQT@&%\/?__Q&5
M]/?__XN5\/?__P^LV0*+A?#Y___!ZP(QVXF5H/K__XN5]/G__P^DPAZ+E73^
M___!X!X)P8N%</[__P6AZ]ENB87H]___BX5`^___@](``;7H]___B[6@^O__
MB97L]___$;WL]___,=(QVC'(B[VD^O__,X7H^___,=H!A>CW__\1E>SW__^+
MA:#Z__\/I/<%BY6D^O__P>8%#ZS0&PGPP>H;,=(!A>CW__\1E>SW__^+E>CW
M__^+O>S[__^+A>C[__^+M>C[__^)E?C\__^+E>S[___'A?S\__\`````#ZS^
M`@^DPAZ+E7S^___!X!X)QHN%>/[__\'O`C'_!:'KV6Z)A>#W__^#T@"+A4#[
M__\!A>#W__^)\(F5Y/?__XN51/O__Q&5Y/?__XGZ,=HQR#':,X6@^O__`87@
M]___$97D]___BX7X_/__BY7\_/__#ZS0&\'J&XF%T/3__XN%^/S__XF5U/3_
M_XN5_/S__P^DP@7!X`6)A=CW__^+A=#T__\+A=CW__^)E=SW__\QT@&%X/?_
M_Q&5Y/?__XN5X/?__XN%H/K__\>%=/S__P````#'A:SZ__\`````B95P_/__
MBY6D^O__#ZS0`L'J`HF%T/?__XN%H/K__XF5U/?__XN5I/K__P^DPAZ)E<ST
M__^+E=#W___!X!Z)A<CT__\)PHN%U/?__PN%S/3__XF5R/?__XF5J/K__XN5
MA/[__XF%S/?__XN%@/[__P6AZ]ENB87`]___@](``8W`]___B97$]___$9W$
M]___,=*+A:CZ__\Q^C':BXUP_/__BYUT_/__QX5,^___`````#'P,X7X_/__
M`87`]___$97$]___BX5P_/__#Z3+!8N5=/S__\'A!8N=_/S__P^LT!L)R(N-
M^/S__\'J&S'2`87`]___$97$]___BY7`]___#ZS9`HN%^/S__\'K`C';B95(
M^___BY7\_/__#Z3"'HN5C/[__\'@'@G!BX6(_O__!:'KV6Z)A;CW__^+A:CZ
M__^#T@`!M;CW__^)E;SW__\1O;SW__\QTC':,<@QVC.%</S__P&%N/?__Q&5
MO/?__XNU2/O__XN53/O__XN%2/O__XN]3/O__\>%_/G__P`````/K-`;#Z3W
M!8N]=/S__\'F!0GPB[5P_/__P>H;,=(!A;CW__\1E;SW__^+E;CW__\/K/X"
MBX5P_/__P>\",?^)E?CY__^+E73\__\/I,(>BY64_O__P>`>"<:+A9#^__\%
MH>O9;HF%L/?__X/2`(N%J/K__P&%L/?__XGPB96T]___BY6L^O__$96T]___
MB?HQVC'(,=HSA4C[__\!A;#W__\1E;3W__^+E?SY__^+A?CY___'A?3[__\`
M````#ZS0&\'J&XF%P/3__XN%^/G__XF5Q/3__XN5_/G__P^DP@7!X`6)A:CW
M__^+A<#T__\+A:CW__^)E:SW__\QT@&%L/?__Q&5M/?__XN5L/?__XN%2/O_
M_XF5\/O__XN53/O__P^LT`+!Z@*)A:#W__^+A4C[__^)E:3W__^+E4S[__\/
MI,(>B96\]/__BY6@]___P>`>B86X]/__"<*+A:3W__\+A;ST__^)E9CW__^)
ME5#[__^)A9SW___'A53[__\`````BX68_O__BY6<_O__QX6T^O__``````6A
MZ]ENB860]___BX50^___@](``8V0]___BXWP^___B964]___$9V4]___,=(Q
M^C'P,=J+G?3[__\SA?CY__\!A9#W__\1E93W__^+A?#[__\/I,L%BY7T^___
MP>$%BYW\^?__#ZS0&PG(BXWX^?__P>H;,=(!A9#W__\1E93W__^+E9#W__\/
MK-D"BX7X^?__P>L",=N)E;#Z__^+E?SY__\/I,(>BY6D_O__P>`>"<&+A:#^
M__\%H>O9;HF%B/?__XN%4/O__X/2``&UB/?__XNUL/K__XF5C/?__Q&]C/?_
M_S'2,=HQR(N]M/K__S.%\/O__S':`86(]___$96,]___BX6P^O__#Z3W!8N5
MM/K__\'F!8N]]/O__\>%!/W__P`````/K-`;"?"+M?#[___!ZALQT@&%B/?_
M_Q&5C/?__XN5B/?__P^L_@*+A?#[___![P(Q_XF5`/W__XN5]/O__P^DPAZ+
ME:S^___!X!X)QHN%J/[__P6AZ]EN@](`B86`]___BX50^___B96$]___BY54
M^___`86`]___B?`1E83W__^)^C':,<@QVC.%L/K__P&%@/?__Q&5A/?__XN%
M`/W__XN5!/W__\>%?/S__P`````/K-`;P>H;B86P]/__BX4`_?__B96T]/__
MBY4$_?__#Z3"!<'@!8F%>/?__XN%L/3__PN%>/?__XF5?/?__S'2`86`]___
M$96$]___BY6`]___BX6P^O__B95X_/__BY6T^O__#ZS0`L'J`HF%</?__XN%
ML/K__XF5=/?__XN5M/K__P^DPA[!X!Z)A:CT__^)E:ST__^+E7#W___'A;SZ
M__\`````"<*+A73W__\+A:ST__^)E;CZ__^)E6CW__^+E;3^__^)A6SW__^+
MA;#^__\%W+P;CXF%8/?__XN%N/K__X/2``&-8/?__XN-N/K__XF59/?__Q&=
M9/?__PGP,=(CA0#]__\)^B'Q(=HA^PG:"<B+G7S\__\!A6#W__\1E63W__^+
MC7C\__^+E7S\__^+A7C\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A6#W__\1E63W
M__^+E6#W__^)E5C[__^+E03]__^+A0#]___'A5S[__\`````QX4,_?__````
M``^LT`+!Z@*)A5CW__^+A0#]__^)E5SW__^+E03]__^+C5CW__\/I,(>BY6\
M_O__P>`>"<&+A;C^__^)C0C]__\%W+P;CXF%4/?__X/2`(G(`;50]___B954
M]___$;U4]___,=(CC;CZ__\)T@N%N/K__S';(X5X_/__(?HAVPG:BYU<^___
M"<B+C5C[__\!A5#W__\1E53W__^+A5C[__^+E5S[__\/I,L%P>$%#ZS0&PG(
MP>H;,=(!A5#W__\1E53W__^+E5#W__^+O7S\__^+A7C\__^+M7C\__^)E0#Z
M__^+E7S\__^+C0C]___'A03Z__\`````#ZS^`@^DPAZ+E<3^___!X!X)QHN%
MP/[__\'O`C'_!=R\&X^)A4CW__^+A;CZ__^#T@`!A4CW__^+A0C]__^)E4SW
M__^+E;SZ__\1E4SW__\QT@GZ,=L)\"'Q(X58^___(?LA^@G:BYT$^O__"<B+
MC0#Z__\!A4CW__\1E4SW__^+A0#Z__^+E03Z__\/I,L%P>$%#ZS0&PG(P>H;
M,=(!A4CW__\1E4SW__^+E4CW__^+A5C[___'A?S[__\`````QX5D^___````
M`(F5^/O__XN57/O__P^LT`+!Z@*)A4#W__^+A5C[__^)E43W__^+E5S[__^+
MC4#W__\/I,(>BY7,_O__P>`>"<&+A<C^__^)C6#[__\%W+P;CXF%./?__X/2
M`(N%"/W__P&%./?__XG(B94\]___BY4,_?__$94\]___"?`QTC';(X4`^O__
M"?HA\2'[(?H)V@G(BYW\^___`84X]___$94\]___BXWX^___BY7\^___BX7X
M^___#Z3+!<'A!0^LT!L)R,'J&S'2`84X]___$94\]___BY4X]___BX4`^O__
MQX7$^O__`````,>%#/K__P````")E<#Z__^+E03Z__\/K-`"P>H"B84P]___
MBX4`^O__B94T]___BY4$^O__BXTP]___#Z3"'HN5U/[__\'@'@G!BX70_O__
MB8T(^O__!=R\&X^)A2CW__^#T@")R`&U*/?__XF5+/?__Q&]+/?__S'2(XU@
M^___"=(+A6#[__\QVR.%^/O__R'Z(=L)VHN=Q/K__PG(BXW`^O__`84H]___
M$94L]___BX7`^O__BY7$^O__#Z3+!<'A!0^LT!L)R,'J&S'2`84H]___$94L
M]___BY4H]___B[W\^___BX7X^___B[7X^___B940_?__BY7\^___BXT(^O__
MQX44_?__``````^L_@(/I,(>BY7<_O__P>`>"<:+A=C^___![P(Q_P7<O!N/
MB84@]___BX5@^___@](``84@]___BX4(^O__B94D]___BY5D^___$94D]___
M,=()^C';"?`A\2.%P/K__R'[(?H)VHN=%/W__PG(BXT0_?__`84@]___$94D
M]___BX40_?__BY44_?__#Z3+!<'A!0^LT!L)R,'J&S'2`84@]___$94D]___
MBY4@]___BX7`^O__QX6$_/__`````,>%S/K__P````")E8#\__^+E<3Z__\/
MK-`"P>H"B848]___BX7`^O__B94<]___BY7$^O__BXT8]___#Z3"'HN5Y/[_
M_\'@'@G!BX7@_O__B8W(^O__!=R\&X^)A1#W__^#T@"+A0CZ__\!A1#W__^)
MR(F5%/?__XN5#/K__Q&5%/?__PGP,=(QVR.%$/W__PGZ(?$A^R'Z"=H)R(N=
MA/S__P&%$/?__Q&5%/?__XN-@/S__XN5A/S__XN%@/S__P^DRP7!X04/K-`;
M"<C!ZALQT@&%$/?__Q&5%/?__XN5$/?__XN%$/W__\>%;/O__P````#'A1S]
M__\`````B95H^___BY44_?__#ZS0`L'J`HF%"/?__XN%$/W__XF5#/?__XN5
M%/W__XN-"/?__P^DPAZ+E>S^___!X!X)P8N%Z/[__XF-&/W__P7<O!N/B84`
M]___@](`B<@!M0#W__^)E03W__\1O03W__\QTB.-R/K__PG2"X7(^O__,=LC
MA8#\__\A^B';"=J+G6S[__\)R(N-:/O__P&%`/?__Q&5!/?__XN%:/O__XN5
M;/O__P^DRP7!X04/K-`;"<C!ZALQT@&%`/?__Q&5!/?__XN5`/?__XN]A/S_
M_XN%@/S__XNU@/S__XF5$/K__XN5A/S__XN-&/W__\>%%/K__P`````/K/X"
M#Z3"'HN5]/[__\'@'@G&BX7P_O__P>\",?\%W+P;CXF%^/;__XN%R/K__X/2
M``&%^/;__XN%&/W__XF5_/;__XN5S/K__Q&5_/;__S'2"?HQVPGP(?$CA6C[
M__\A^R'Z"=J+G13Z__\)R(N-$/K__P&%^/;__Q&5_/;__XN%$/K__XN5%/K_
M_P^DRP7!X04/K-`;"<C!ZALQT@&%^/;__Q&5_/;__XN5^/;__XN%:/O__\>%
M!/S__P````#'A73[__\`````B94`_/__BY5L^___#ZS0`L'J`HF%\/;__XN%
M:/O__XF5]/;__XN5;/O__XN-\/;__P^DPAZ+E?S^___!X!X)P8N%^/[__XF-
M</O__P7<O!N/B87H]O__@](`BX48_?__`87H]O__B<B)E>SV__^+E1S]__\1
ME>SV__\)\#'2,=LCA1#Z__\)^B'Q(?LA^@G:"<B+G03\__\!A>CV__\1E>SV
M__^+C0#\__^+E03\__^+A0#\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A>CV__\1
ME>SV__^+E>CV__^+A1#Z___'A=3Z__\`````QX4<^O__`````(F5T/K__XN5
M%/K__P^LT`+!Z@*)A>#V__^+A1#Z__^)E>3V__^+E13Z__^+C>#V__\/I,(>
MBY4$____P>`>"<&+A0#___^)C1CZ__\%W+P;CXF%V/;__X/2`(G(`;78]O__
MB97<]O__$;W<]O__,=(CC7#[__\)T@N%</O__S';(X4`_/__(?HAVPG:BYW4
M^O__"<B+C=#Z__\!A=CV__\1E=SV__^+A=#Z__^+E=3Z__\/I,L%P>$%#ZS0
M&PG(P>H;,=(!A=CV__\1E=SV__^+E=CV__^+O03\__^+A0#\__^+M0#\__^)
ME2#]__^+E03\__^+C1CZ___'A23]__\`````#ZS^`@^DPAZ+E0S____!X!X)
MQHN%"/___\'O`C'_!=R\&X^)A=#V__^+A7#[__^#T@`!A=#V__^+A1CZ__^)
ME=3V__^+E73[__\1E=3V__\QT@GZ,=L)\"'Q(X70^O__(?LA^@G:BYTD_?__
M"<B+C2#]__\!A=#V__\1E=3V__^+A2#]__^+E23]__\/I,L%P>$%#ZS0&PG(
MP>H;,=(!A=#V__\1E=3V__^+E=#V__^+A=#Z___'A8S\__\`````QX7<^O__
M`````(F5B/S__XN5U/K__P^LT`+!Z@*)A<CV__^+A=#Z__^)E<SV__^+E=3Z
M__^+C<CV__\/I,(>BY44____P>`>"<&+A1#___^)C=CZ__\%W+P;CXF%P/;_
M_X/2`(N%&/K__P&%P/;__XG(B97$]O__BY4<^O__$97$]O__"?`QTC';(X4@
M_?__"?HA\2'[(?H)V@G(BYV,_/__`87`]O__$97$]O__BXV(_/__BY6,_/__
MBX6(_/__#Z3+!<'A!0^LT!L)R,'J&S'2`87`]O__$97$]O__BY7`]O__BX4@
M_?__QX5\^___`````,>%+/W__P````")E7C[__^+E23]__\/K-`"P>H"B86X
M]O__BX4@_?__B96\]O__BY4D_?__BXVX]O__#Z3"'HN5'/___\'@'@G!BX48
M____B8TH_?__!=R\&X^)A;#V__^#T@")R`&UL/;__XF5M/;__Q&]M/;__S'2
M(XW8^O__"=(+A=CZ__\QVR.%B/S__R'Z(=L)VHN=?/O__PG(BXUX^___`86P
M]O__$96T]O__BX5X^___BY5\^___#Z3+!<'A!0^LT!L)R,'J&S'2`86P]O__
M$96T]O__BY6P]O__B[V,_/__BX6(_/__B[6(_/__B94@^O__BY6,_/__BXTH
M_?__QX4D^O__``````^L_@(/I,(>BY4D____P>`>"<:+A2#____![P(Q_P7<
MO!N/B86H]O__BX78^O__@](``86H]O__BX4H_?__B96L]O__BY7<^O__$96L
M]O__,=()^C';"?`A\2.%>/O__R'[(?H)VHN=)/K__PG(BXT@^O__`86H]O__
M$96L]O__BX4@^O__BY4D^O__#Z3+!<'A!0^LT!L)R,'J&S'2`86H]O__$96L
M]O__BY6H]O__BX5X^___QX4,_/__`````,>%A/O__P````")E0C\__^+E7S[
M__\/K-`"P>H"B86@]O__BX5X^___B96D]O__BY5\^___BXV@]O__#Z3"'HN5
M+/___\'@'@G!BX4H____B8V`^___!=R\&X^)A9CV__^#T@"+A2C]__\!A9CV
M__^)R(F5G/;__XN5+/W__Q&5G/;__PGP,=(QVR.%(/K__PGZ(?$A^R'Z"=H)
MR(N=#/S__P&%F/;__Q&5G/;__XN-"/S__XN5#/S__XN%"/S__P^DRP7!X04/
MK-`;"<C!ZALQT@&%F/;__Q&5G/;__XN5F/;__XN%(/K__\>%+/K__P````"+
MG2SZ___'A>3Z__\`````B97@^O__BY4D^O__#ZS0`L'J`HF%D/;__XN%(/K_
M_XF5E/;__XN5)/K__XN-D/;__P^DPAZ+E33____!X!X)P8N%,/___XF-*/K_
M_P7<O!N/@](`B86(]O__B<@!M8CV__^)E8SV__^+E2SZ__\1O8SV__\CC8#[
M__\CG83[__\+A8#[__\+E83[__\CA0C\__\CE0S\__\)R`G:`86(]O__$96,
M]O__BXW@^O__BY7D^O__BX7@^O__BYWD^O__B[T,_/__B[4(_/__#ZS0&P^D
MRP6+G2SZ___!X04)R(N-*/K__\'J&S'2`86(]O__$96,]O__BY6(]O__#ZS^
M`HN%"/S__\'O`C'_QX4T_?__`````(F5,/W__XN5#/S__P^DPAZ+E3S____!
MX!X)QHN%./___P7<O!N/B86`]O__@](`BX6`^___`86`]O__BX4H^O__B96$
M]O__BY6$^___$96$]O__(?&+E2SZ__\A^PGP(X7@^O__"?HCE>3Z__\)R`G:
M`86`]O__$96$]O__BXTP_?__BY4T_?__BX4P_?__BYTT_?__QX64_/__````
M`,>%[/K__P`````/K-`;#Z3+!<'A!0G(P>H;,=(!A8#V__\1E83V__^+E8#V
M__^+A>#Z__^)E9#\__^+E>3Z__\/K-`"P>H"B85X]O__BX7@^O__B95\]O__
MBY7D^O__BXUX]O__#Z3"'HN51/___\'@'@G!BX5`____B8WH^O__!=R\&X^)
MA7#V__^#T@"+A2CZ__\!A7#V__^)R(F5=/;__XN5+/K__Q&5=/;__PGP,=(Q
MVR.%,/W__PGZ(?$A^R'Z"=H)R(N=E/S__P&%</;__Q&5=/;__XN-D/S__XN5
ME/S__XN%D/S__\>%C/O__P`````/I,L%P>$%#ZS0&PG(P>H;,=(!A7#V__\1
ME73V__^+E7#V__^+A3#]___'A3S]__\`````B96(^___BY4T_?__#ZS0`L'J
M`HF%:/;__XN%,/W__XF5;/;__XN5-/W__XN-:/;__P^DPAZ+E4S____!X!X)
MP8N%2/___XF-./W__P7<O!N/B85@]O__@](`B<@!M6#V__^)E63V__\1O63V
M__\QTB.-Z/K__PG2"X7H^O__,=LCA9#\__\A^B';B[50____"=J+G8S[__\)
MR(N-B/O__P&%8/;__Q&59/;__XN%B/O__XN5C/O__P^DRP7!X06+G93\___'
MA33Z__\`````#ZS0&PG(BXV0_/__P>H;,=(!A6#V__\1E63V__^+E6#V__\/
MK-D"BX60_/__P>L",=N)E3#Z__^+E93\__\/I,(>BY4T^O__P>`>"<&+A3C]
M__^!QM;!8LH#M>CZ__\QR#.%B/O__P'&BX4P^O__#ZS0&\'J&XF%H/3__XF5
MI/3__XN%,/K__XN5-/K__XN]C/O__\>%%/S__P`````/I,(%P>`%B858]O__
MBX6@]/__"X58]O__B95<]O__BY6,^___`<:+A8C[__^)M1#\__^+M8C[__\/
MI,(>BY5<____#ZS^`L'@'@G&BX58____P>\",?\%UL%BRHF%4/;__X/2`(N%
M./W__P&%4/;__XGPB954]O__BY4\_?__$954]O__B?HQVC'(,=HSA3#Z__\!
MA5#V__\1E53V__^+A1#\__^+E13\__\/K-`;P>H;B868]/__BX40_/__B96<
M]/__BY44_/__#Z3"!<'@!8F%2/;__XN%F/3__PN%2/;__XF53/;__S'2`850
M]O__$954]O__BY50]O__BX4P^O__QX7T^O__`````,>%//K__P````")E?#Z
M__^+E33Z__\/K-`"P>H"B85`]O__BX4P^O__B95$]O__BY4T^O__#Z3"'HF5
ME/3__XN50/;__\'@'HF%D/3__PG"BX5$]O__"X64]/__B94X]O__B94X^O__
MBY5D____B84\]O__BX5@____!=;!8LJ)A3#V__^#T@`!C3#V__^)E33V__\1
MG33V__\QTHN%./K__S'Z,=J+C?#Z__^+G?3Z___'A43]__\`````,?`SA1#\
M__\!A3#V__\1E33V__^+A?#Z__\/I,L%BY7T^O__P>$%BYT4_/__#ZS0&PG(
MBXT0_/__P>H;,=(!A3#V__\1E33V__^+E3#V__\/K-D"BX40_/__P>L",=N)
ME4#]__^+E13\__\/I,(>BY5L____P>`>"<&+A6C___\%UL%BRHF%*/;__XN%
M./K__X/2``&U*/;__XF5+/;__Q&]+/;__S'2,=HQR#':,X7P^O__`84H]O__
M$94L]O__B[5`_?__BY5$_?__BX5`_?__B[U$_?__QX6<_/__``````^LT!L/
MI/<%B[WT^O__P>8%"?"+M?#Z___!ZALQT@&%*/;__Q&5+/;__XN5*/;__P^L
M_@*+A?#Z___![P(Q_XF5F/S__XN5]/K__P^DPAZ+E73____!X!X)QHN%</__
M_P76P6+*B84@]O__@](`BX4X^O__`84@]O__B?")E23V__^+E3SZ__\1E23V
M__^)^C':,<@QVC.%0/W__P&%(/;__Q&5)/;__XN5G/S__XN%F/S__\>%E/O_
M_P`````/K-`;P>H;B86(]/__BX68_/__B96,]/__BY6<_/__#Z3"!<'@!8F%
M&/;__XN%B/3__PN%&/;__XF5'/;__S'2`84@]O__$94D]O__BY4@]O__BX5`
M_?__B960^___BY5$_?__#ZS0`L'J`HF%$/;__XN%0/W__XF5%/;__XN51/W_
M_P^DPAZ)E83T__^+E1#V___!X!Z)A8#T__\)PHN%%/;__PN%A/3__XF5"/;_
M_XF52/W__XF%#/;__\>%3/W__P````"+A7C___^+E7S____'A43Z__\`````
M!=;!8LJ)A0#V__^+A4C]__^#T@`!C0#V__^+C9#[__^)E03V__\1G03V__\Q
MTC'Z,?`QVHN=E/O__S.%F/S__P&%`/;__Q&5!/;__XN%D/O__P^DRP6+E93[
M___!X06+G9S\__\/K-`;"<B+C9C\___!ZALQT@&%`/;__Q&5!/;__XN5`/;_
M_P^LV0*+A9C\___!ZP(QVXF50/K__XN5G/S__P^DPAZ+583!X!X)P8M%@`76
MP6+*B87X]?__BX5(_?__@](``;7X]?__B[5`^O__B97\]?__$;W\]?__,=(Q
MVC'(B[U$^O__,X60^___,=H!A?CU__\1E?SU__^+A4#Z__\/I/<%BY5$^O__
MP>8%B[V4^___QX4<_/__``````^LT!L)\(NUD/O__\'J&S'2`87X]?__$97\
M]?__BY7X]?__#ZS^`HN%D/O__\'O`C'_B948_/__BY64^___#Z3"'HM5C,'@
M'@G&BT6(!=;!8LJ#T@")A?#U__^+A4C]__^)E?3U__^+E4S]__\!A?#U__^)
M\!&5]/7__XGZ,=HQR#':,X5`^O__`87P]?__$97T]?__BX48_/__BY4<_/__
MQX7\^O__``````^LT!O!ZAN)A7CT__^+A1C\__^)E7ST__^+E1S\__\/I,(%
MP>`%B87H]?__BX5X]/__"X7H]?__B97L]?__,=(!A?#U__\1E?3U__^+E?#U
M__^+A4#Z__^)E?CZ__^+E43Z__\/K-`"P>H"B87@]?__BX5`^O__B97D]?__
MBY5$^O__#Z3"'L'@'HF%</3__XF5=/3__XN5X/7__\>%3/K__P`````)PHN%
MY/7__PN%=/3__XF52/K__XF5V/7__XM5E(F%W/7__XM%D`76P6+*B870]?__
MBX5(^O__@](``8W0]?__BXWX^O__B974]?__$9W4]?__,=(Q^C'P,=J+G?SZ
M__\SA1C\__\!A=#U__\1E=3U__^+A?CZ__\/I,L%BY7\^O__P>$%#ZS0&PG(
MP>H;,=(!A=#U__\1E=3U__^+E=#U__^)E5#]__^+G1S\__^+A1C\__^+C1C\
M__^+E1S\___'A53]__\`````QX6D_/__``````^LV0(/I,(>BU6<P>`>"<&+
M19C!ZP(QVP76P6+*B87(]?__BX5(^O__@](``;7(]?__B[50_?__B97,]?__
M$;W,]?__,=(QVC'(B[U4_?__,X7X^O__,=H!A<CU__\1E<SU__^+A5#]__\/
MI/<%BY54_?__P>8%B[W\^O__#ZS0&PGPB[7X^O__P>H;,=(!A<CU__\1E<SU
M__^+E<CU__\/K/X"BX7X^O__P>\",?^)E:#\__^+E?SZ__\/I,(>BU6DP>`>
M"<:+1:`%UL%BRHF%P/7__X/2`(N%2/K__P&%P/7__XGPB97$]?__BY5,^O__
M$97$]?__B?HQVC'(,=HSA5#]__\!A<#U__\1E<3U__^+A:#\__^+E:3\___'
MA9S[__\`````#ZS0&\'J&XF%:/3__XN%H/S__XF5;/3__XN5I/S__P^DP@7!
MX`6)A;CU__^+A6CT__\+A;CU__^)E;SU__\QT@&%P/7__Q&5Q/7__XN5P/7_
M_XN%4/W__XF5F/O__XN55/W__P^LT`+!Z@*)A;#U__^+A5#]__^)E;3U__^+
ME53]___'A5S]__\`````#Z3"'HF59/3__XN5L/7__\'@'HF%8/3__PG"BX6T
M]?__"X5D]/__B958_?__B96H]?__BU6LB86L]?__BT6H!=;!8LJ)A:#U__^+
MA5C]__^#T@`!C:#U__^+C9C[__^)E:3U__\1G:3U__\QTC'Z,?`QVHN=G/O_
M_S.%H/S__P&%H/7__Q&5I/7__XN%F/O__P^DRP6+E9S[___!X04/K-`;"<C!
MZALQT@&%H/7__Q&5I/7__XN5H/7__XN=I/S__XN%H/S__XN-H/S__XF54/K_
M_XN5I/S__\>%5/K__P`````/K-D"#Z3"'HM5M,'@'@G!BT6PP>L",=L%UL%B
MRHF%F/7__XN%6/W__X/2``&UF/7__XNU4/K__XF5G/7__Q&]G/7__S'2,=HQ
MR(N]5/K__S.%F/O__S':`868]?__$96<]?__BX50^O__#Z3W!8N55/K__\'F
M!0^LT!L)\,'J&S'2`868]?__$96<]?__BY68]?__B94@_/__B[V<^___BX68
M^___B[68^___BY6<^___QX4D_/__``````^L_@(/I,(>BU6\P>`>"<:+1;C!
M[P(Q_P76P6+*B860]?__@](`BX58_?__`860]?__B?")E93U__^+E5S]__\1
ME93U__^)^C':,<@QVC.%4/K__P&%D/7__Q&5E/7__XN%(/S__XN5)/S__P^L
MT!O!ZAN)A5CT__^+A2#\__^)E5ST__^+E23\__\/I,(%P>`%B86(]?__BX58
M]/__"X6(]?__B96,]?__,=(!A9#U__\1E93U__^+E9#U__^+A5#Z___'A03[
M__\`````QX5<^O__`````(F5`/O__XN55/K__P^LT`+!Z@*)A8#U__^+A5#Z
M__^)E83U__^+E53Z__\/I,(>B954]/__BY6`]?__P>`>B850]/__"<*+A83U
M__\+A53T__^)E5CZ__^)E7CU__^+5<2)A7SU__^+1<`%UL%BRHF%</7__XN%
M6/K__X/2``&-</7__XF5=/7__Q&==/7__S'2,?HQ\#':,X4@_/__`85P]?__
M$95T]?__BY4$^___BXT`^___BX4`^___BYT$^___QX5D_?__``````^LT!L/
MI,L%BYTD_/__P>$%"<B+C2#\___!ZALQT@&%</7__Q&5=/7__XN5</7__P^L
MV0*+A2#\___!ZP(QVXF58/W__XN5)/S__P^DPAZ+5<S!X!X)P8M%R`76P6+*
MB85H]?__BX58^O__@](``;5H]?__B[5@_?__B95L]?__$;UL]?__,=(QVC'(
MB[UD_?__,X4`^___,=H!A6CU__\1E6SU__^+A6#]__\/I/<%BY5D_?__P>8%
M#ZS0&PGPP>H;,=(!A6CU__\1E6SU__^+E6CU__^+O03[__^+A0#[__^+M0#[
M__^)E:C\__^+E03[___'A:S\__\`````#ZS^`@^DPAZ+5=3!X!X)QHM%T,'O
M`C'_!=;!8LJ)A6#U__^#T@"+A5CZ__\!A6#U__^)\(F59/7__XN57/K__Q&5
M9/7__XGZ,=HQR#':,X5@_?__`85@]?__$95D]?__BX6H_/__BY6L_/__#ZS0
M&\'J&XF%2/3__XN%J/S__XF53/3__XN5K/S__P^DP@7!X`6)A5CU__^+A4CT
M__\+A5CU__^)E5SU__\QT@&%8/7__Q&59/7__XN58/7__XN%8/W__\>%I/O_
M_P````#'A6S]__\`````B96@^___BY5D_?__#ZS0`L'J`HF%4/7__XN%8/W_
M_XF55/7__XN59/W__P^DPAZ)E43T__^+E5#U___!X!Z)A4#T__\)PHN%5/7_
M_PN%1/3__XF52/7__XF5:/W__XM5W(F%3/7__XM%V`76P6+*B85`]?__@](`
M`8U`]?__B95$]?__$9U$]?__,=*+A6C]__\Q^C':BXV@^___BYVD^___QX5D
M^O__`````(N]9/K__S'P,X6H_/__`85`]?__$95$]?__BX6@^___#Z3+!8N5
MI/O__\'A!<>%M/S__P`````/K-`;"<C!ZALQT@&%0/7__Q&51/7__XN50/7_
M_XN%J/S__XF58/K__XN5K/S__P^LT`+!Z@*)A3CU__^+A:C\__^)E3SU__^+
ME:S\__^+C3CU__\/I,(>BY5D^O__P>`>"<&)C;#\__^+3>"+A;#\__^!P=;!
M8LH!\8NU8/K__S.%:/W__S.%H/O__P'!BX5@^O__#Z3W!<'F!0^LT!L)\,'J
M&P'!B8TH_/__BYVD^___BX6@^___BXV@^___BY6D^___BW7HQX4L_/__````
M``^LV0(/I,(>BY4L_/__P>`>"<&+A;#\___!ZP*!QM;!8LH#M6C]__\QR#.%
M8/K__P'&BX4H_/__#ZS0&\'J&XF%./3__XN%*/S__XF5//3__XN5+/S__P^D
MP@7!X`6)A3#U__^+A3CT__\+A3#U__^)E33U__\!QHGPB[64^?__`X4@]?__
MQT8$`````(D&B[TH_/__`7X(QT8,`````(N59/K__XNU8/K__XN%8/K__XN]
M9/K__P^LT`(/I/<>P>8>"?"+M93Y___!Z@(!1A`!3AC'1A0`````QT8<````
M`(N]L/S__P%^(,=&)`````"!Q+P+``!;7E]=PXUT)@"-O"<`````58GE@^PH
MA<")??R)QXE=](EU^(E5Z'4/,<"+7?2+=?B+??R)[%W#H?!F!0B%P(E%['3E
M#[8'A,!U1,=%\`````"+5>R+&H7;=,Z)UHUT)@"+1?")?"0$B1PDB40D".B=
MLO__A<!U"XM5\(T$$X`X/70IBUX$@\8$A=MUU.N:/#V)^G2V@\(!#[8"A,!U
M!RGZB57PZZP\/77KZ_,K=>R#P`&+5>C!_@*),NEL____9I!5B>564XG#C77T
M@^P0B?*)V.@Z____A<!T+XVV`````(M%](T4A0`````#%?!F!0B#P@2+`H7`
MB4+\=?2)\HG8Z`O___^%P'77@\006UY=PU6)Y8/L&(U5_.CR_O__R<-5B>6#
M[`B#/0AB!0C_=`>A"&(%",G#N"#_!`CHT/___X7`=`</M@"$P'45,<"C"&(%
M"*$(8@4(R<.-M"8`````/#`/E<`/ML#KXXVV`````%6)Y8/L",<$)/_____H
MGK#__\=$)`0`````QP0DH.,$".CZLO__R<.0C;0F`````%6)Y5.#[!2A:&(%
M"(M(!*%48@4(#[=0$`^V!2AB!0AF@>+_`8/@?\'B!PG"9HE1`J%H8@4(BU@$
MQT0D!`````#'!"2_``4(Z!2R__^)0QRA:&(%"(M0!*%@8@4(B4(@H6AB!0@Q
MTHM(!*&X8@4(A<!T`XM0;(E1)*%H8@4(BT`$QT`H`````*%H8@4(BT`$QT`8
M`````*%H8@4(BU`$H6QB!0B)0BR#Q!1;7<.-="8`58GE5U93@^Q\A<")18QT
M!8`X`'4+@\1\6UY?7<.-=@")!"3H*+'__X7`B460=.:0BT60B00DZ%6O__^%
MP`^$J0```(U8"+\K_P0(_+D"````B=[SIG39ORK_!`BY`P```(G>\Z9TR8M%
MC(D$).B^K___B1PDB<;HM*___XU$!@*)!"3H**[__XE<)`R)QHM%C,=$)`0M
M_P0(B30DB40D".A+K___C464B40D!(DT).CLKO__@\`!=!`/MT6<)0#P```]
M`$```'1!B30DZ*^N__^)-"3H!['__XM%D(D$).BLKO__A<`/A5?___^+19")
M!"3H*;'__XM%C(D$).BNK___@\1\6UY?7<.)\.CO_O__Z[Z-M@````"-O"<`
M````58GE4XG#@^QTC46<B40D!(D<).A(K___A<!U%P^W1:0E`/```#T`0```
M=!0]`*```'0-@\1T,<!;7<.0C70F`(D<),=$)`0"````Z("O__^%P`^4P(/$
M=%L/ML!=PV:058GE5U:)UE.#["R)1=PQP(`Z/0^4P`'&B30DZ)"N__^-5?")
M1>"+1=SH$OS__X7`B<-T*HD$).ATKO__.47@#X>?````#[8&@\8!B`.#PP&$
MP'7Q@\0L,<!;7E]=PZ'P9@4(,=NZ"````(L(A<ET$8/#`8L\F(7_=?:-%)T(
M````BPW`8@4(A<D/A0T!``#'!<!B!0@!````B10DZ(^L__^%P(E%V`^$$0$`
M`*'P9@4(C3R=`````(E\)`B)1"0$BT78B00DZ,6O__^+5=B)%?!F!0BA\&8%
M",=$!P0`````B5WPBU7<#[8"A,`/A*,````\/0^$FP```(VV`````(/"`0^V
M`H3`=7N)T"M%W(M-X(M=\(U$"`+!XP*)!"0#'?!F!0CH!JS__X7`B0,/A(D`
M``"+5?"A\&8%"(L,D(M5W`^V`H3`B`%T'3P]=!F)T.L(@\`!@/H]=`T/ME`!
M@\$!A-*($77KQ@$]B<J-=@`/M@:#Q@&(0@&#P@&$P'7PZ<_^__\\/0^%<___
M_XUV`.EU____,<#I<____XE4)`2)!"3H"*[__X7`H_!F!0AT#(T\G0````#I
M%____X/$++C_____6UY?7<.-M@````!5B>57OSW_!`A64X/L3(`]/?\$"`#'
M1=P]_P0(QT7@,_\$",=%Y$#_!`C'1>@V_P0(QT7L._\$",=%\+\`!0@/A,0`
M``"-7=SK'XVV`````(M5"(GXZ-;]__^+>P2#PP2`/P`/A*````")^.@`^___
MA<")QG3:@#@`=-6+10B)-"2)1"0$Z):M__^%P'7,BU4(B10DZ$>L__^)1="A
M+`$%"(D$).@WK/__BU70B30DC40"`8E%S.@EK/__`T7,B00DZ)JJ__^+50B)
M="00QT0D!&0`!0B)5"0(B47(H2P!!0B)1"0,BT7(B00DZ+"K__^+5<B)^.@V
M_?__BWL$@\,$@#\`#X5@____@\1,6UY?7</K#9"0D)"0D)"0D)"0D)!5B>57
M5H/L,*&`8@4(B47T,<"A!`$%"(E%TJ$(`04(B476H0P!!0B)1=JA$`$%"(E%
MWJ$4`04(B47BH1@!!0B)1>:A'`$%"(E%ZJ$@`04(B47N#[<%)`$%"&:)1?*X
M3?\$".B9^?__N%;_!`CHC_G__[A>_P0(Z(7Y__^X9_\$".A[^?__N&[_!`CH
M<?G__[A^_P0(Z&?Y__^XBO\$".A=^?__N"#_!`CH4_G__[B3_P0(Z$GY__^X
MG?\$".@_^?__N*?_!`CH-?G__[BT_P0(Z"OY__^XO?\$".@A^?__N,C_!`CH
M9_G__X7`=`R)PKB3_P0(Z!?\__^XV?\$".A-^?__A<!T#(G"N.O_!`CH_?O_
M_[CV_P0(Z#/Y__^%P'0OB<*XBO\$".CC^___NB(`!0BX;O\$".C4^___BT7T
M,P6`8@4(=4:#Q#!>7UW#9I"X!@`%".CV^/__A<!T#HG"N"#_!`CHIOO__^O!
M_(UUX[\7``4(N0H```#SIG6OC57MN"#_!`CHA?O__^N@Z`ZK__^-M"8`````
MC;PG`````%6)Y8/L".AUJO__B00DZ*VH__\QTH7`=`*+$,F)T,.058GE@^P8
MB5WTBUT(B77XB7W\A=MT"0^V.XGXA,!U&,=%""O_!`B+7?2+=?B+??R)[%WI
M>:G__XD<).C!J?__`=B-4/\YTW,FBPTH`04(#[9`_P^V,8GQ.,AT#.LVC78`
M#[8*.,%U;(/J`3G3<O(YVG4PBQ4H`04(B?@Z`G2ABPTH`04(B4T(ZYV-M"8`
M````#[8"B?$XP735@^H!.=-R\.O,@^H!.=-S#8L-*`$%"`^V`CH!=.PIVC')
MC4("/0`$``!V$XM=](G(BW7XBWW\B>Q=PXG(Z[R-0@&)1"0(B5PD!,<$).!B
M!0CHXJG__[G@8@4(Z\^-="8`C;PG`````%6)Y8/L&(E=^(M="(EU_(D<).CI
M_O__B00DZ#&L__^)QNAZ]___A<!T"87;=`6`.P!U#8M=^(MU_(GL7<.-=@#'
M1"0$)``%"(DT).CPJ?__.<9UWXMU_(G8BUWXB>Q=Z6SX__^-M@````"-OP``
M``"-3"0$@^3P_W'\C4$(58GE5XG/5E-1@^P8B40D"(U!!(E$)`2)#"3H-*K_
M_X`]I&(%"``/A!X!``"`#4!B!0@#,=*+#U*-0050WRPD@\0(W`6P`04(W06X
M`04(V<G:Z=_@G@^'2`$``(T$C10```")!"3HB:G__Z/L9@4(B<&+1P2+`,=!
M!"D`!0C'00C@`04(QT$,+``%"(D!QP7H9@4(!````(L?@_L!#X[>````BW<$
MC4'\N@$```")1>R-=@"+!):)1)$,@\(!.=-_\HM%[,=$F!``````QT0D$```
M``")3"0,BP?'1"0$H/X$"(/``XE$)`BAX&8%"(D$).@]IO__A<")PW1PH>!F
M!0B)!"3H*JC__[A^_P0(Z`#V__^%P'0@H>!F!0B)!"3H[Z7__^@ZI___@\08
MB=A96UY?78UA_,.AY&8%"(7`=$N)!"3H._[__^O-Z+2F__^%P*/@9@4(=%^)
M!"3H8Z?__\8%(&(%"`#IP/[__Z'@9@4(B00DZ.JE__^)P^E\____C4'\B47L
MZ3;___^XBO\$".A^]?__A<"CY&8%"'6BZ73____'1"0$I6(%",<$)+8`!0CH
M;*C__\<$)`$```#H4*C__U6)Y5=64X'LG`0``(M]"*&`8@4(B47P,<"XBO\$
M"(M=#.@J]?__BS4H`04(B3PDB70D!(F%@/O__^C"I___A<!T*(GZN*?_!`CH
MPO?__XM5\#,5@&(%"(GX#X5X`0``@<2<!```6UY?7<.)/"3H3J;__XL5+`$%
M"(D<)(E4)`2)A7S[___H9J7__X7`B<-TLHN%?/O__X/``8F%>/O__Y"`.P!U
M!;LK_P0(BX6`^___A<!T&HN5@/O__XE<)`2)%"3H^J?__X7`#X2Q````B1PD
MZ.JE__^)P0^V1`/_.@9U%8T4"P^V0OZ#Z0'&0O\`@^H!.@9T[HN%>/O__P'(
M/?\#```/CSG___^-E?#[__^)%"2)?"00B70D#(E<)`C'1"0$9``%".A5I?__
MC860^___B40D!(V%\/O__XD$).CMI/__A<!U$P^WA9C[__\E`/```#T`@```
M=#Z+%2P!!0C'!"0`````B50D!.B`I/__B<.%VP^%)O___^G#_O__H2P!!0C'
M!"0`````B40D!.A<I/__B</KVHV5\/O__\=$)`0!````B10DZ-*E__^%P'6H
MC97P^___N*?_!`CH3O;__XV%\/O__XD$).B@I/__B<?I=_[__^C$I?__C70F
M`%6)Y5=64X'L7($``(M%"(L5@&(%"(E5[#'2QX44?___+P`%",>%&'___S<`
M!0B)A<A^__^XBO\$",>%''___RO_!`C'A2!___^_``4(QX7\?O__Z_\$",>%
M`'___^3_!`C'A01___]!``4(QX4(?___,@`%",>%#'___TD`!0C'A1!___^_
M``4(QX4D?___30`%",>%*'___U(`!0C'A2Q___^_``4(Z,3R__^%P(G#=`F`
M.``/A?,"``"0C70F`.C[^?__NP$```"-M21___^%P(G'#X2T`@``#[8'A,!T
M+HGY#[[0A=)X%SL52&(%"'T/H:!B!0CW1)`T``4``'4#Q@%?#[9!`8/!`83`
M==2[`0```,>%S'[__P````#K#8N%S'[__X/#`87`=4"+A)WX?O__@#@`#X2)
M`@``Z"[R__^%P(G&=-CH@_3__X7`D'3.B30D@\,!Z#.C__^)A<Q^__^+A<Q^
M__^%P'3`BXW,?O__B0PDZ&6C__^)/"2)P^A;H___C9P#!`0``(D<).C,H?__
MB1PDB870?O__Z+ZA__^)?"04BSTH`04(QT0D$"0`!0C'1"0$8@`%"(E\)`R)
MA<1^__^+A<Q^__^+E<1^__^)1"0(B10DZ,*B__^+C<1^___'1"0$[0$``(D,
M).A<H___N#;_!`CH<O'__X7`#X2;`0``B00DZ(*B__^+O<A^__^)1"0$BP>)
M!"3H_OO__X7`B<,/A'4!``")'"3HK*+__X/X`XF%N'[__P^/R0$``.@X\?__
MA<!U'L=$)`0`````B1PDZ%2A__^%P(F%U'[__P^%-@(``+HB``4(N"#_!`CH
MM_/__S';Z+"C__^+#2@!!0B+O<1^___'1"04OP`%",=$)`2)``4(B4PD#(E\
M)`B)1"00BX70?O__B00DZ.JA___K3.@SH___@S@1=5WH::/__XL5*`$%"(/#
M`8N-Q'[__XN]T'[__\=$)!B_``4(B5PD%(E4)`R)1"00B4PD",=$)`27``4(
MB3PDZ)RA__^+A=!^___'1"0$[0$``(D$).@VHO__@\`!=)F+E<1^__^)%"3H
M8Z/__XN5T'[__[B*_P0(Z//R__^+C=!^__^)#"3HM?3__XM][#,]@&(%"(N%
MT'[__P^%H@<``('$7($``%M>7UW#D(UT)@#H^^___X7`=`J)!"3H#Z'__XG'
M@\,!A?\/A4S]__^+1)[\@#@`==F_6P`%".EN_?__BX7(?O__BQCI?O[__XD$
M).A*]/__B1PDZ-*@__^)A=!^___KA;X!````ZQ2-=@"+A<Q^__^#Q@&%P`^%
MC/W__XN<M1!___^`.P`/A'S]__^)V.C8\?__A<!TU(D<).B,H/__B87,?O__
MZ\2-=`/\N`4```#\OVL`!0B)P?.F#X4>_O__@[VX?O__!'09B[VX?O__BQ4H
M`04(#[9$'_LZ`@^%_/W__XN-R'[__XM)!(7)B8V\?O__#X3E_?__B0PDZ'J@
M__^#^`,/AM3]__^+O;Q^__^Y!0```/R-=`?\N'``!0B)Q_.F#X6U_?__BYV\
M?O__Z:K]__^-M"8`````QT0D#`(```#'1"0$[O___\=$)`C_____B00DZ!"@
M__^+E=1^__^-A3!____'1"0(!@```(E$)`2)%"3H(*#__X"],'___P!U#8"]
M,7___T,/A%<%``"+E=1^___'1"0,`````,=$)`0`````QT0D"`````")%"3H
MM)___\>%,/___P$C16?'A33___\`````QX4X____B:O-[\>%//___P````#'
MA4#____^W+J8QX5$____`````,>%2/___W94,A#'A4S___\`````QX50____
M\.'2P\>%5/___P````#'A5C___\`````QX5<____`````,>%8/___P````#'
MA63___\`````QT6H`````)"+E=1^__^-A3!____'1"0(`(```(E$)`2)%"3H
M,)___X7`B87L?O__#XZK`0``BX58____BY5<____B878?O__BX7L?O__B97<
M?O__B<*)P<'Z'XG3#Z3"`\'@`P.%V'[__S'_.;W<?O__B<9R&'<(.878?O__
M=@Z#A6#___\!@Y5D____`(M%J`^LV1W!ZQT!C6#___\1G63___^%P(FU6/__
M_XVU,'___XF]7/___XV]:/___P^$BP```.FW````BP:)A6C___^+1@2)A6S_
M__^+1@B)A7#___^+1@R)A73___^+1A")A7C___^+1A2)A7S___^+1AB)18"+
M1AR)182+1B")18B+1B2)18R+1BB)19"+1BR)192+1C")19B+1C2)19R+1CB)
M1:"+1CR#QD"#K>Q^__]`B46DC84P____Z'FA__^#O>Q^__\_#X]M____BXWL
M?O__B3PDB70D!(E,)`CH]I[__XN]['[__XE]J.F(_O__BYWL?O__ND`````I
MPCG3?@*)TXV]:/___XT$!XV5,'___XE<)`B)5"0$B00DZ+:>__^)V`-%J(/X
M0(E%J`^%1?[__XVU,'___XV%,/___P'>*9WL?O__Z.R@___I;O___XN-U'[_
M_XD,).@9G?__BY5<____BX58____BYU@____B[5D____B97D?O__B87@?O__
M#ZS0`XG!@^$_P>H#C5$!@_HXQH0I:/___X`/CDL"``"X0````"G0C90I:?__
M_XD4)(V]:/___XE$)`C'1"0$`````.@]GO__C84P____Z&*@__^Y#@```#'`
M_/.KB?*)V`^LT!B(1:#!ZAB)V(GR#ZS0$(A%H<'J$(G8B?(/K-`(B$6BP>H(
MBX7@?O__BY7D?O__C76OB%VCC7W8#ZS0&(A%I,'J&(N%X'[__XN5Y'[__P^L
MT!"(1:7!ZA"+A>!^__^+E>1^__\/K-`(P>H(#[:5X'[__XA%IHV%,/___XA5
MI^C.G___BXTP____BYTT____B<B)V@^LT!B(1=C!ZAB)R(G:#ZS0$(A%V<'J
M$(G(B=J+G3S___^(3=N+C3C___\/K-`(B$7:P>H(B=J)R`^LT!B(1=S!ZAB)
MR(G:#ZS0$(A%W<'J$(G(B=J+G43___^(3=^+C4#___\/K-`(B$7>P>H(B=J)
MR`^LT!B(1>#!ZAB)R(G:#ZS0$(A%X<'J$(G(B=J+G4S___^(3>.+C4C___\/
MK-`(B$7BP>H(B=J)R`^LT!B(1>3!ZAB)R(G:#ZS0$(A%Y<'J$(G(B=J+G53_
M__^(3>>+C5#___\/K-`(B$7FP>H(B=J)R`^LT!B(1>C!ZAB)R(G:#ZS0$(A%
MZ<'J$(G(B=HQVP^LT`B(1>K!Z@B(3>L/M@0[@\,!B30D@\8"QT0D!(0`!0B)
M1"0(Z,&:__^#^Q1UW8L]*`$%"(U-KXN%Q'[__XN5T'[__\9%UP#'1"04OP`%
M"(E,)!")?"0,B40D",=$)`1U``4(B10DZ'^:___I^?C__[@X````*="-E"EI
M____B40D",=$)`0`````B10DZ/B;___IR_W__X"],G___T$/A9SZ__^`O3-_
M__]##X6/^O__@+TT?___2`^%@OK__X"]-7___T4/A77Z__^+C=1^__^-O3!_
M___'1"0,`@```,=$)`3&____QT0D"/____^)#"3H(YK__XN%U'[__XE\)`3'
M1"0(*0```(D$).@YFO__BPTH`04(B7PD$(N%T'[__XN]Q'[__\=$)!2_``4(
MB4PD#,=$)`1U``4(B7PD"(D$).BCF?__Z1WX___HN9K__XGVC;PG`````%6)
MY8'L.`@``*&`8@4(B47P,<")7?2-G>_[__^)=?B)??SH^9K__\=$)`RH``4(
MQT0D!*T`!0B)'"2)1"0(Z$V9__^%P'D<,=N+5?`S%8!B!0B)V'54BUWTBW7X
MBWW\B>Q=PXV][O?__\=$)`@`!```B7PD!(D<).@3F/__A<")QGC$C4`!B00D
MZ,*7__^%P'2UB<.)="0(B7PD!(D$).A<FO__Q@0S`.N?Z`&:__^058GE7>E'
M____C;0F`````%6X;O\$"(GE5U93@^P<Q@5D8@4(`>B&Y___A<!T"8`X,0^$
MN0$``.@D[?__QT0D"`L```#'1"0$`0```,<$)+D`!0CHR)?__X7`#X2.````
MBT`,,?:#/>AF!0@!BW@8?FR[`0```.LIBU`,H>QF!0B+!)B)5"0$B00DZ)&:
M__^%P'5*@\8!@\,!.1WH9@4(?CS'1"0(`````(ET)`2)/"3H"YG__X7`="2+
M`/9`"01UM\=$)`@"````QT0D!`````")!"3H9YK__XG"ZYZ+%>AF!0B-0O\Y
M\`^$W````,=$)`@$````QT0D!`$```#'!"2^``4(Z!:7__^%P(G#="3'1"0$
MP``%"(M`#(L`B00DZ`N7__^+0PR+`/9`"D`/A=$```#'1"0(!````,=$)`0!
M````QP0DQO\$".C0EO__A<")QG0CN*?_!`CH4.;__X7`#X2M````B40D!(M&
M#(L`B00DZ+>6__^XBO\$",8%9&(%"`#'!5!B!0@`````Z!SF__^%P*/D9@4(
M#X3/````QT0D!.T!``")!"3HWY?__X7`=`V#^!%T"(/X_XUV`'5^@\0<6UY?
M7<.#Z@$/CAO___^[`0```(D\)(/#`>@MEO__.1WH9@4(?^WI_O[__X!X`0`/
MA$+^__^-M@````#I,O[__XD$).@#F/__C78`Z1_____HYOW__X7`B<-FD'1"
MB40D!(M&#(L`B00DZ/V5__^)'"3HE9C__^DY____B40D#*'D9@4(B40D"*'L
M9@4(BP#'!"1@`04(B40D!.A<F/__H>QF!0B+`.GX_O__H>QF!0B)!"3HP_'_
M_XL=[&8%"*/D9@4(BT8,BP#V0`D$=#Z+0`R)7"0$B00DZ+Z5__^)PXM&#(L`
M]D`)!'0\BT`,B40D"*'L9@4(B5PD#(L`QP0D,`$%"(E$)`3H[Y?__\=$)`@"
M````QT0D!`````")!"3H5YC__^NKQT0D"`(```#'1"0$`````(D$).@]F/__
MZZV-="8`C;PG`````%6)Y8/L&,=$)`C%``4(QT0D!)"4!`C'!"3/``4(Z*Z7
M___)PXVV`````(V_`````%6)Y8/L&.C%____QT0D$`````#'1"0,OP`%",=$
M)`B_``4(QT0D!'#[!`C'!"3K``4(Z-F5___)PY"0D)"0D)!5B>53@^P$H0!@
M!0B#^/]T$C';_]"+@_Q?!0B#ZP2#^/]U\(/$!%M=PY"0D(/L#.A<F/__@\0,
MPP``````````4$%27T-,14%.`"XN`"5S+R5S`$Q)0E!!5$@`1%E,1%],24)2
M05)97U!!5$@`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!0
M05)?0T%#2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%2
M7T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P
M87(M`"UE`"TM`$,Z7%1%35``+W9A<B]T;7`O`%1%35!$25(`5$U0`%5315(`
M55-%4DY!344`4UE35$5-`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M
M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!F:6QE
M`"]P<F]C+R5I+R5S`$%21U8`&`!P97)L`'!E<FQX<VDN8P!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`.@```%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````#\`!0@``04()7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`````````````````
M@/___\]!<&%R+G!L```````````````````````````````````C(2]U<W(O
M8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T
M(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S
M92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@
M1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C
M92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T
M87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG
M('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP
M:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL
M:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A
M8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N
M9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO
M(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N
M)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@
M<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@
M=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@
M("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,
M24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR
M9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@
M("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@
M(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I
M.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I
M;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*
M("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6
M>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E
M('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[
M)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R
M;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I
M;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@
M("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I
M;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L
M("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S
M<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R
M.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@
M("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@
M(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL
M;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B
M)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@
M("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE
M*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O
M=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@
M("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@
M("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D
M97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]
M/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@
M("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@
M("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C
M('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@
M("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@
M("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R
M:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D
M9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@
M("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D
M;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL
M(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O
M8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN
M9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@
M("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@
M9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@
M4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@
M("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@
M("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC
M('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O
M<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@
M("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@
M("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@
M("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P
M<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S
M92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R
M=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R
M;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE
M(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T
M($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%2
M1U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G
M22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*
M("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@
M("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O
M=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*
M("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@
M("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@
M>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN
M:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*
M("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P
M;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*
M:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[
M"B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z
M:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@
M)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A
M;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A
M<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@
M("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U
M="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@
M("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P
M-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@
M("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O
M(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U
M;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D
M=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@
M(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@
M("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@
M("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@
M('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O
M(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG
M(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P
M;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H
M(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE
M8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD
M:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@
M4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O
M(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@
M("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@
M("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F
M:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@
M("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@
M("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@
M("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I
M;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P
M96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D[
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@
M("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@
M("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@
M(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N
M=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@
M*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@
M("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D
M;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@
M("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@
M?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@
M;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS
M."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@
M("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*
M("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G
M;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*
M("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!0
M05(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@
M("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@
M("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@
M("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@
M("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@
M("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@
M("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@
M("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@
M("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@
M("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*
M(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[
M>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A
M<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@
M;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@
M("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*
M("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@
M<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I
M<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E
M($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@
M1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@
M24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E
M($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q
M=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H
M92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT
M;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!4
M96UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@
M("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@
M("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@
M+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N
M86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O
M<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O
M7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P
M-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D
M9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@
M("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@
M('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@
M/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U
M9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@
M("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,
M14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@
M("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@
M("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@
M)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F
M:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3
M971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@
M>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@
M("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@
M("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R
M;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@
M(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E
M;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@
M("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U
M8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA
M8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D
M96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS
M92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*
M"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.
M5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%2
M7U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@
M('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*
M"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO
M9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@
M(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN
M:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@
M("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I
M.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P
M86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH````!&P,[$`````$`
M``#D./__+````!0``````````7I2``%\"`$;#`0$B`$``!@````<````L#C_
M_QD`````0PX$0H4"#04`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_____`````/____\```````````$````!`````0``
M`/X!```!````"`(```$````6`@```0```","```/````<P,```P```#<D@0(
M#0````S_!`@$````9($$"`4```#HB@0(!@```(B$!`@*````MP0```L````0
M````%0`````````#````!&$%"`(```#8`0``%````!$````7````!)$$"!$`
M``",D`0($@```'@````3````"````/[__V]LD`0(____;P$```#P__]OH(\$
M"```````````````````````````````````````````````````````````
M`````!1@!0@```````````:3!`@6DP0()I,$"#:3!`A&DP0(5I,$"&:3!`AV
MDP0(AI,$"):3!`BFDP0(MI,$",:3!`C6DP0(YI,$"/:3!`@&E`0(%I0$"":4
M!`@VE`0(1I0$"%:4!`AFE`0(=I0$"(:4!`B6E`0(II0$"+:4!`C&E`0(UI0$
M".:4!`CVE`0(!I4$"!:5!`@FE00(-I4$"$:5!`A6E00(9I4$"':5!`B&E00(
MEI4$"*:5!`BVE00(QI4$"-:5!`CFE00(]I4$"`:6!`@6E@0()I8$"#:6!`A&
ME@0(5I8$"&:6!`AVE@0(AI8$"):6!`BFE@0(OP`%"``````,8`4(_____\`!
M!0CI6P```"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]I,S@V+65L9B]C<G0Q7W,N
M4RQV(#$N-2`R,#$Q+S`Q+S$S(#(S.C`P.C(R(&MI8B!%>'`@)```)$9R965"
M4T0Z('-R8R]L:6(O8W-U+VDS.#8M96QF+V-R=#%?8RYC+'8@,2XR(#(P,3`O
M,3(O,#D@,C$Z,S$Z,C$@9&EM($5X<"`D`"1&<F5E0E-$.B!S<F,O;&EB+V-S
M=2]C;VUM;VXO8W)T8G)A;F0N8RQV(#$N-R`R,#$Q+S`Q+S$S(#(P.C0T.C,Q
M(&1I;2!%>'`@)`!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A
M<V4@6T9R965"4T1=```D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O
M8W)T:2Y3+'8@,2XY(#(P,3$O,#$O,#<@,38Z,#<Z-3$@:VEB($5X<"`D``!'
M0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@6T9R965"4T1=
M``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@
M6T9R965"4T1=```D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O8W)T
M;BY3+'8@,2XX(#(P,3$O,#$O,#<@,38Z,#<Z-3$@:VEB($5X<"`D```N<VAS
M=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O="YP
M;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M``````````````````````````L````!`````@```#2!!`@T`0``%0``````
M`````````0`````````3````!P````(```!,@00(3`$``!@`````````````
M``0`````````(0````4````"````9($$"&0!```D`P``!``````````$````
M!````"<````+`````@```(B$!`B(!```8`8```4````!````!````!`````O
M`````P````(```#HB@0(Z`H``+<$``````````````$`````````-P```/__
M_V\"````H(\$"*`/``#,````!``````````"`````@```$0```#^__]O`@``
M`&R0!`AL$```(`````4````!````!`````````!3````"0````(```",D`0(
MC!```'@````$``````````0````(````7`````D````"````!)$$"`01``#8
M`0``!`````L````$````"````&4````!````!@```-R2!`C<$@``$0``````
M````````!`````````!@`````0````8```#PD@0(\!(``,`#````````````
M``0````$````:P````$````&````L)8$"+`6``!<:``````````````0````
M`````'$````!````!@````S_!`@,?P``#```````````````!`````````!W
M`````0````(````@_P0(('\``*I>`````````````"``````````?P````$`
M```"````S%T%",S=```4```````````````$`````````(T````!`````@``
M`.!=!0C@W0``.```````````````!`````````"7`````0````,`````8`4(
M`.````@```````````````0`````````G@````$````#````"&`%"`C@```(
M```````````````$`````````*4````!`````P```!!@!0@0X```!```````
M````````!`````````"J````!@````,````48`4(%.```/`````%````````
M``0````(````LP````$````#````!&$%"`3A``#X```````````````$````
M!````+P````!`````P```/QA!0C\X0``&```````````````!`````````#"
M````"`````,````@8@4(%.(``-0$`````````````"``````````QP````$`
M`````````````!3B``!K`@`````````````!``````````$````#````````
=``````!_Y```T````````````````0``````````
